@@ -153,7 +153,13 @@ class Sf:
         bulk = SalesforceBulk(sessionId = self.session_id, host = self.instance)
         self.bulk = bulk
         # SFDC Metadata API
-        sfMeta = SfdcSession(session_id=self.session_id, instance=".".join(self.instance.split(".")[:2]))
+        sf_meta_instance = ""
+        if self.instance.__contains__("my.salesforce.com"):
+            sf_meta_instance = self.instance.replace("my.salesforce.com","my")
+        else:
+            sf_meta_instance = ".".join(self.instance.split(".")[:2])
+            
+        sfMeta = SfdcSession(session_id=self.session_id, instance=sf_meta_instance)
         self.sfMeta = sfMeta
         # Alternative way to authenticate using SFDC Metadata API
         # sfMeta = SfdcSession(username=sfUsername,password=sfPassword,token='',is_sandbox=isSandbox)
@@ -984,9 +990,9 @@ class Sf:
             
         try:
             response = requests.get(f"{self.veeva_common['Veeva_Server_vod__c'][0]}/{self.veeva_common['Veeva_Version_vod__c'][0]}?VER={self.veeva_common['Veeva_Version_vod__c'][0]}&SSID={self.session_id}&url=https://{self.instance}/services/Soap/u/24.0/{self.org_info['Id'][0]}&ses={self.session_id}&oType=networkAdmin&event=getSFCredentials")
-            return response.json()
+            return {'status': response.status_code, 'response': response.json()}
         except:
-            return {"error": "Unable to get network admin credentials"}
+            return {'status': 500, 'response': {"error": "Unable to get network admin credentials"}}
         
     def get_network_admin_network_user_info(self):
         
@@ -998,9 +1004,9 @@ class Sf:
             
         try:
             response = requests.get(f"{self.veeva_common['Veeva_Server_vod__c'][0]}/{self.veeva_common['Veeva_Version_vod__c'][0]}?VER={self.veeva_common['Veeva_Version_vod__c'][0]}&SSID={self.session_id}&url=https://{self.instance}/services/Soap/u/24.0/{self.org_info['Id'][0]}&ses={self.session_id}&oType=networkAdmin&event=getNetworkCredentials")
-            return response.json()
+            return {'status': response.status_code, 'response': response.json()}
         except:
-            return {"error": "Unable to get network admin credentials"}
+            return {'status': 500, 'response': {"error": "Unable to get network admin credentials"}}
 
     @serialze_zeep
     def metadata_read(self, metadata_type: str, fullName: str):
